{% set formActive = True if webenv.toppage != 'tag' else False %}
{% set classList = "active" if formActive else "" %}
{% set showHideText = "hide" if formActive else "show"%}
<form action="/awt#results" method="POST">
  <fieldset id="ABIF_submission_area">
    <legend>ABIF submission area
(<a href="#" id="abifshowhide" onclick="javascript:toggleShowHide({target:'abifbox', targactive: {{"true" if formActive else "false"}}});">{{showHideText}}</a>)
    </legend>
    <div id="abifbox" class="{{classList}}">
    <textarea id="abifinput" name="abifinput"
              rows="{{ webenv.inputRows }}" cols="{{ webenv.inputCols }}"
              placeholder="{{ msgs.placeholder }}"
              >{{ abifinput }}</textarea><br>
    <input type="checkbox" name="include_dotsvg" value="yes" checked>pairwise dot diagram?&nbsp;
    <input type="checkbox" name="include_pairtable" value="yes" checked>pairwise table?&nbsp;
    <input type="checkbox" name="include_FPTP" value="yes" checked>FPTP results?&nbsp;
    <input type="checkbox" name="include_IRV" value="yes" checked>IRV results?&nbsp;
    <input type="checkbox" name="include_STAR" value="yes" checked>STAR results?&nbsp;
    <input type="submit" value="Submit" id="submitButton">
    </div>
  </fieldset>
</form>
