<!DOCTYPE html>
{% set debug_flag = webenv.debugFlag %}
{% set statstr = webenv.statusStr %}
{% set my_url = webenv.req_url %}
<html>
  <head>
      <meta charset="UTF-8">
      <title>{{msgs.pagetitle}}</title>
      <link rel="stylesheet"
            type="text/css"
            href="{{ url_for('static', filename='css/electostyle.css') }}">
      <link rel="shortcut icon"
            href="{{ url_for('static', filename='img/awtonly.svg') }}">
      <script src="{{ url_for('static', filename='js/abifwebtool.js') }}" defer></script>
  </head>
  <body>
    <header>
      <a href="/">
        <img src="/static/img/awt-electorama.svg" alt="awt logo">
      </a>
    </header>
    <div id="content">
      <h1>{{msgs.pagetitle}}</h1>
      {% if webenv.debugFlag %}
      <div class="hatnote">(<a href="#debug">Debug output</a>)</div>
      <small><i>{{webenv.req_url}} {{webenv.hostname}}</i></small>
      (see <a href="#debug">debug output below</a>)<br>
      {% endif %}
      {% block introduction %}
      {% if webenv.toppage == 'awt' %}
      {% include 'intro-snippet.html' %}
      {% endif %}
      {% endblock introduction %}
      {% block content %}
      {########### vvvv THIS GETS REPLACED vvvv #########}
      <h1>THIS OUTPUT SHOULD BE OVERRIDEN BY A JINJA SUBTEMPLATE</h1>
      {########### ^^^^ THIS GETS REPLACED ^^^^ #########}
      {% endblock content %}
      {% if webenv.debugFlag %}
      <h2 id="debug">Debug output</h2>
      <div class="hatnote">from {{webenv.hostname}} for
        <a href="{{webenv.req_url}}">{{webenv.req_url}}</a></div>
      <pre>{{ debug_output }}</pre>
      <code>resblob</code> var:
      <pre>{{ resblob|pprint}}</pre>
      <code>msgs</code> var:
      <pre>{{ msgs|pprint}}</pre>
      <code>webenv</code> var:
      <pre>{{ webenv|pprint }}</pre>
      {% endif %}
      <hr>
      {% include 'footer.snippet.html' %}
    </div>
  </body>
</html>
