<style>
.footer {
  display: flex;
  align-items: center;
}

.footer-text {
    flex-grow: 1;
    margin-left: 2em;
    margin-right: 2em;
}
</style>
<p>
  <div class="footer">
    <div>
      <a href="https://abif.electorama.com">
        <img height="50px" src="/static/img/awtonly.svg" alt="awt logo">
      </a>
    </div>
    <div class="footer-text">
      <em><a href="https://abif.electorama.com">abif.electorama.com</a>
        is maintained as part of
        the <a href="https://electorama.com">electorama.com</a> family of websites.
      </em>
      <br>
      <em>Source
        code: </em><code><a href="https://github.com/electorama/abiftool">
          github.com/electorama/abiftool</a></code><em> (for the core library)
        and </em><code><a href="https://github.com/electorama/awt">github.com/electorama/awt</a></code>
      <em>(for the web presentation code)</em><br>
      <em>Bug reports:</em><code>
        <a href="https://github.com/electorama/awt/issues">
          github.com/electorama/awt/issues</a>
      </code>
      <br>
      <em>Copyright © 2024, 2025 by <a href="https://robla.net/">Rob Lanphier</a> &mdash;
        All Rights Reserved.  Licensed under the
        <a href="https://www.gnu.org/licenses/agpl-3.0.en.html">AGPL 3.0</a>.</em>
    </div>
    <div>
      <a href="https://electorama.com">
        <img height="50px" src="/static/img/electodrop.svg" alt="awt logo">
      </a>
    </div>
  </div>
</p>
