<h1>ABIF</h1>
<p>"ABIF" stands for "<a href="https://electowiki.org/wiki/ABIF"
                         >Aggregated Ballot Information Format</a>".</p>
<p>See the <a href="#examples">ABIF examples</a> section at the bottom of this page</a> to see. To tally election results expressed using ABIF, enter valid abif below...</p>
