{% extends "base.html" %}
{% block content %}
<h2>Elections by tag</h2>
<ul>
  {% for item in tagarray %}
  <li>{{loop.index}}. <a href="/tag/{{item}}">{{item}}</a></li>
  {% endfor %}
  <li><a href="/awt">/awt homepage</a></li>
</ul>
{% include 'election-list-snippet.html' %}
<p>See also: the <a href="/id">full list of elections</a> on this website. In addition to
   the above elections, one may return to the <a href="/awt">/awt homepage</a>
   and enter an ABIF-formatted election into the form field.</p>
{% endblock content %}
