<h2>Election list</h2>
<ul>
    {% for item in election_list %}
  <!--<p>{{ item.desc }}</p>-->
  <li class="election-item">
    <span class="election-id">
      {{loop.index}}. <a href="/id/{{item.id}}">{{item.id}}</a>
    </span>
    <span class="election-tags">
      (tags: {% for t in item.taglist %}
        <a href="/tag/{{t}}">{{t}}</a>{% if not loop.last %}, {% endif %}
      {% endfor %})
    </span>
  </li>
  <ul>
    <li>{{item.title}}</li>
    <li>{{ item.desc }}</li>
  </ul>
  {% endfor %}
</ul>
