<h2>Also note</h2>
<p>One may explore the tagged data on this website:
  <ul>
  <li><a href="/tag">Elections by tag</a></li>
  <li><a href="/id">List of all elections</a></li>
  </ul>
</p>

<p>One may find other examples in both the
  <a href="https://github.com/electorama/abif/tree/main/testfiles">abif repository test files</a> and the
  <a href="https://github.com/electorama/abiftool/tree/main/testdata">abiftool repository test files</a>.</p>
<p>The web version of abiftool is very restricted compared to the "abiftool" Python application:</p>
<ul>
  <li><a href="https://electorama.com/abiftool/">electorama.com/abiftool</a></li>
</ul>
<p>See the <a href="https://electowiki.org/wiki/ABIF">"ABIF" electowiki article</a> for more information about ABIF.</p>
