<div class="tab-content" id="all">
  <h3>Examples organized by tag</h3>
  <ul>
    {% for item in tagarray %}
    <li>{{loop.index}}. <a href="/tag/{{item}}">{{item}}</a></li>
    {% endfor %}
  </ul>
  <p>See <a href="/tag">all tags and all examples on this website</a>.</p>
</div>
